@@ -24,17 +24,17 @@ from .featurewiz import FE_transform_numeric_columns, FE_create_interaction_vars
 from .stacking_models import Stacking_Classifier, Blending_Regressor
 from .featurewiz import EDA_binning_numeric_column_displaying_bins, FE_add_lagged_targets_by_date_category
 from .featurewiz import FE_convert_mixed_datatypes_to_string, FE_drop_rows_with_infinity
-from .featurewiz import EDA_find_columns_with_infinity
+from .featurewiz import EDA_find_columns_with_infinity, FE_split_list_into_columns
 ################################################################################
 if __name__ == "__main__":
     module_type = 'Running'
 else:
     module_type = 'Imported'
 version_number = __version__
-print("""%s featurewiz: advanced feature engg and selection library. Version=%s
-output = featurewiz(dataname, target, corr_limit=0.70,
-                    verbose=2, sep=',', header=0, test_data='',
-                    feature_engg='', category_encoders='')
+print("""%s featurewiz with Dask. Restart kernel after installation. Version=%s
+output = featurewiz(dataname, target, corr_limit=0.70, verbose=2, sep=',', 
+		header=0, test_data='',feature_engg='', category_encoders='',
+		dask_xgboost_flag=True, nrows=None)
 Create new features via 'feature_engg' flag : ['interactions','groupby','target']
                                 """ %(module_type, version_number))
 ################################################################################
